# MIT License
#
# Copyright (c) 2019-2020 Nihaal Sangha
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

try:
    from importlib.metadata import version as _version
except ModuleNotFoundError:
    _version = lambda _: None

try:
    import colorama as _colorama
except ImportError:  # pragma: no cover
    _colorama = None
if _colorama is not None:
    _colorama.init()

try:
    from click import echo as _click_echo
except ImportError:  # pragma: no cover
    _click_echo = None

__all__ = ['echo', 'CLEAR_LINE']
__version__ = _version('pecho')

START_OF_LINE = '\r'
CLEAR_LINE = '\033[K'

_sentinel = object()


def echo(*objects, newline=False, newline_char='\n', end='', print_func=print, print_func_kwargs=_sentinel):
    if print_func_kwargs is _sentinel:
        print_func_kwargs = {}

    if objects:
        objects = (START_OF_LINE + CLEAR_LINE + str(objects[0]),) + objects[1:]
    else:
        objects = (START_OF_LINE + CLEAR_LINE,)

    if newline is True:
        end += newline_char

    if end:
        objects = objects[:-1] + (str(objects[-1]) + end,)

    if print_func == print:
        print_func_kwargs['end'] = ''
    elif print_func == _click_echo:
        # Can ignore `print_func is None` as print_func() will error
        print_func_kwargs['nl'] = False

    return print_func(*objects, **print_func_kwargs)



import sys
from typing import Any, Callable, Dict, List, Optional, Protocol, TextIO, TypeVar, Union, overload

__all__: List[str]

try:
    import importlib.metadata
except ImportError:
    __version__: None
else:
    __version__: str

_PrintFuncArg = TypeVar('_PrintFuncArg')
_PrintFuncReturn = TypeVar('_PrintFuncReturn')

class PrintFuncText(Protocol):
    def __call__(self, __text: _PrintFuncArg, *__args: Any, **__kwargs: Any) -> _PrintFuncReturn: ...

class PrintFuncObjects(Protocol):
    def __call__(self, *__objects: _PrintFuncArg, **__kwargs: Any) -> _PrintFuncReturn: ...

@overload
def echo(
    __text: _PrintFuncArg,
    newline: bool = ...,
    newline_char: str = ...,
    end: str = ...,
    print_func: PrintFuncText = ...,
    print_func_kwargs: Dict[str, Any] = ...,
) -> _PrintFuncReturn: ...
@overload
def echo(
    *objects: _PrintFuncArg,
    newline: bool = ...,
    newline_char: str = ...,
    end: str = ...,
    print_func_kwargs: Dict[str, Any] = ...,
) -> _PrintFuncReturn: ...
def echo(
    *objects: _PrintFuncArg,
    newline: bool = ...,
    newline_char: str = ...,
    end: str = ...,
    print_func: PrintFuncObjects = ...,
    print_func_kwargs: Dict[str, Any] = ...,
) -> _PrintFuncReturn: ...



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pecho']

package_data = \
{'': ['*']}

extras_require = \
{'windows': ['colorama>=0.4.3,<0.5.0']}

setup_kwargs = {
    'name': 'pecho',
    'version': '0.5.2',
    'description': 'Easy way to write things like status bars',
    'long_description': "# pecho\n[![Tests](https://github.com/nihaals/pecho/workflows/Tests/badge.svg)](https://github.com/nihaals/pecho/actions?query=workflow%3ATests)\n[![codecov](https://codecov.io/gh/nihaals/pecho/branch/master/graph/badge.svg)](https://codecov.io/gh/nihaals/pecho)\n[![PyPI](https://img.shields.io/pypi/v/pecho)](https://pypi.org/project/pecho/)\n[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pecho)](https://pypi.org/project/pecho/)\n[![PyPI - Wheel](https://img.shields.io/pypi/wheel/pecho)](https://pypi.org/project/pecho/)\n\nPecho makes it easy to write things like status bars.\n\n## Usage\n```python\nfrom pecho import echo\n\necho('1%')  # 1%\necho('2%')  # Replaces with 2%\necho('3%', newline=True)  # Replaces with 3% and appends a newline\necho('4%')  # 3%\\n4%\n```\n",
    'author': 'Nihaal Sangha',
    'author_email': 'me@niha.al',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/nihaals/pecho',
    'packages': packages,
    'package_data': package_data,
    'extras_require': extras_require,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
